@@ -1,11 +1,22 @@
 #!/usr/bin/env python
 
+# 2014-05-16 clean(): debug
+#            keepd, keepm, keeps did not work
+#            integer was used in if-clauses instead of string 
+#            corrected the if-clauses like: if keepd == 1  -> if keepd == '1'
+#
+# 2014-05-16 readparam : debug
+#            polmode is only available in sirpol.param
+#            but it tried to read polmode from sirius.param
+#            if self.omode == 'sirpol': added before it trues to read polmode
+#
 # 2014-02-14 to ignore cases for the sky prefix and to remove _ before the sky prefix
 
 import glob
 import os
 import sys
 import re
+import shutil
 import math
 import pyfits
 from pyraf import iraf
@@ -73,6 +84,10 @@ class readparam:
         if self.cfitsio != '0' and self.cfitsio != '1': 
             print '%s : invalid value for cfitsio' % self.cfitsio
             flag = 1
+        if self.omode == 'sirpol':
+            if self.polmode != '1' and self.polmode != '2' and self.polmode != '3': 
+                print '%s : invalid value for polmode' % self.polmode
+                flag = 1
         if self.keepd != '0' and self.keepd != '1': 
             print '%s : invalid value for keepd' % self.keepd
             flag = 1
@@ -1376,148 +1391,28 @@ def polsky(polmode, numpoldict):
             fo4.close()
 
 
-def mkqui(numpoldict, blist):
-
-    SCRIPTDIR = os.path.realpath(os.path.dirname(sys.argv[0]))
-
-    fo1 = open('mkqu.sh', 'w')
-    fo2 = open('mki.sh', 'w')
-    fin = open('dithlistlist')
-    for line in fin:
-        v = line[:-1].split()
-        qflag = 0
-        uflag = 0
-        fin2 = open(v[0])
-        for line2 in fin2:
-            v2 = line2[:-1].split()
-            if numpoldict[v2[0]] == 0.0:
-                q1 = v2[0]
-            elif numpoldict[v2[0]] == 45.0:
-                q2 = v2[0]
-                if int(q2) - int(q1) == 1:
-                    for band in blist:
-                        print >> fo1, '%s/spmkqux %sf%s.fits %sf%s.fits %sq%s.fits' % (SCRIPTDIR, band, q1, band, q2, band, q1)
-                    qflag = 1
-            elif numpoldict[v2[0]] == 22.5:
-                u1 = v2[0]
-            elif numpoldict[v2[0]] == 67.5:
-                u2 = v2[0]
-                if int(u2) - int(u1) == 1:
-                    for band in blist:
-                        print >> fo1, '%s/spmkqux %sf%s.fits %sf%s.fits %su%s.fits' % (SCRIPTDIR, band, u1, band, u2, band, u1)
-                    uflag = 1
-
-            if qflag == 1 and uflag == 1:
-                for band in blist:
-                    print >> fo2, '%s/spmkix %sf%s.fits %sf%s.fits %sf%s.fits %sf%s.fits %si%s.fits' % (SCRIPTDIR, band, q1, band, q2, band, u1, band, u2, band, q1)
-                qflag = 0
-                uflag = 0
-            elif uflag == 1:
-                uflag = 0
-
-        fin2.close()
-    fin.close()
-    fo1.close()
-    fo2.close()
-
-
-
-def mkvi(numpoldict, blist):
-
-    SCRIPTDIR = os.path.realpath(os.path.dirname(sys.argv[0]))
-
-    fo1 = open('mkv.sh', 'w')
-    fo2 = open('mki.sh', 'w')
-    fin = open('dithlistlist')
-    for line in fin:
-        v = line[:-1].split()
-        qflag = 0
-        fin2 = open(v[0])
-        for line2 in fin2:
-            v2 = line2[:-1].split()
-            if numpoldict[v2[0]] == 0.0:
-                q1 = v2[0]
-            elif numpoldict[v2[0]] == 90.0:
-                q2 = v2[0]
-                if int(q2) - int(q1) == 1:
-                    for band in blist:
-                        print >> fo1, '%s/spmkqux %sf%s.fits %sf%s.fits %sv%s.fits' % (SCRIPTDIR, band, q1, band, q2, band, q1)
-                    qflag = 1
-
-            if qflag == 1:
-                for band in blist:
-                    print >> fo2, '%s/addfitsf %sf%s.fits %sf%s.fits %si%s.fits' % (SCRIPTDIR, band, q1, band, q2, band, q1)
-                qflag = 0
-
-        fin2.close()
-    fin.close()
-    fo1.close()
-    fo2.close()
-
-
-
-def mki(numpoldict, blist):
-
-    SCRIPTDIR = os.path.realpath(os.path.dirname(sys.argv[0]))
-
-    fo1 = open('mki.sh', 'w')
-    fin = open('dithlistlist')
-    for line in fin:
-        v = line[:-1].split()
-        qflag = 0
-        uflag = 0
-        fin2 = open(v[0])
-        for line2 in fin2:
-            v2 = line2[:-1].split()
-            if numpoldict[v2[0]] == 0.0:
-                q1 = v2[0]
-            elif numpoldict[v2[0]] == 90.0:
-                q2 = v2[0]
-                if int(q2) - int(q1) == 1:
-                    qflag = 1
-            elif numpoldict[v2[0]] == 45.0:
-                u1 = v2[0]
-            elif numpoldict[v2[0]] == 135.0:
-                u2 = v2[0]
-                if int(u2) - int(u1) == 1:
-                    uflag = 1
-
-            if qflag == 1 and uflag ==1:
-                for band in blist:
-                    print >> fo1, '%s/spmkix %sf%s.fits %sf%s.fits %sf%s.fits %sf%s.fits %si%s.fits' % (SCRIPTDIR, band, q1, band, q2, band, u1, band, u2, band, q1)
-                qflag = 0
-                uflag = 0
-            elif uflag == 1:
-                uflag = 0
-
-        fin2.close()
-    fin.close()
-    fo1.close()
-
-
-
 def clean(keepd, keeps, keepm):
     
     print 'cleaning the working directory... '
 
-    if keepd == 1 or keeps ==1 or keepm ==1:
+    if keepd == '1' or keeps == '1' or keepm == '1':
         os.mkdir('calib')
 
-    if keepd ==1:
+    if keepd == '1':
         for file in glob.glob('*dark*.fits'):
             shutil.move(file, 'calib')
     else:
         for file in glob.glob('*dark*.fits'):
             os.remove(file)
 
-    if keeps ==1:
+    if keeps == '1':
         for file in glob.glob('*sky*.fits'):
             shutil.move(file, 'calib')
     else:
         for file in glob.glob('*sky*.fits'):
             os.remove(file)
             
-    if keepm ==1:
+    if keepm == '1':
         for file in glob.glob('*mask.fits'):
             shutil.move(file, 'calib')
     else:
